<?php 

class SearchSelect {
  private $iterator;
  private $scope  = "";
  private $dbValue = "";
  private $dbRowId = 0;
  private $message = "";
  private $label;
  
  public function __construct ($entry) {
    if (isset($entry)) {
      $this->label    = $entry->label;
      $this->scope    = $entry->scope;
      $this->iterator = $entry->iterator;
      $this->dbValue  = $entry->dbValue;
      $this->dbRowId  = $entry->dbRowId;
      $this->message  = $entry->message;
 
      if ($this->dbValue === "")
        $this->attribute = "placeholder='Type some characters'";
      else
        $this->attribute = "value='$this->dbValue'";

      if (isset($entry->selectId))
        $this->selectId = $entry->selectId;
      else
        $this->selectId = 0;

      $this->postMessages = "";
      if (null !== $entry->listeners) {
        $listeners = explode(",", $entry->listeners);
        for ($i=0; $i<count($listeners); $i++) {
          $this->postMessages .= "listener" . $listeners[$i] . "(msgContent); ";
        }
      }    
    }
  }
  
  public function outputLayout() {
  
    $layout = "

<label style='width:100%'>$this->label<br></label>    
<div id='togsearch$this->scope'>    
  <input id='search$this->scope' type='text' class='$this->iterator'
    name='$this->scope'	$this->attribute autofocus 
    onkeyup='result$this->scope (this.value)'>
  <div id='hint$this->scope' style='position:relative;'></div>
</div>
<div id=togselect$this->scope> 
  <select id='select$this->scope' class='$this->iterator' style='height:27px;' >
    <option value=0 selected>$this->prompt</option>
     ";

    foreach ($this->options as $item) {
      $value = $item->id;
      $hint  = $item->hint;
 	  $attribute = "";	

      if ($item->id == $this->selectId)
        $attribute = " selected";

      $layout .= "
    <option value=" . $value . $attribute . " >" . $hint . "</option>
      ";
    }
  
    $layout .= "
  </select>
</div>
    ";
	return $layout;
  }
  
  public function outputScript() {
		
    $script = " 	 

var selectId$this->scope = $this->selectId; 
var setState$this->scope = 'formentry';

$(document).ready(function() {
  document.getElementById('togselect$this->scope').style.display='none';
});

$(document).on('click', '#search$this->scope', function (e) {
  $('#$this->scope').val('');
  var msgContent = [];
  msgContent.$this->scope = [0,'', 'formentry'];
  $this->postMessages
});  

$(document).on('change', '#select$this->scope', function (e) {

  if (setState$this->scope == 'formentry') {
    selectId$this->scope = $(this).val();
    var selOption = $(this).text();
    set$this->scope$this->iterator (selectId$this->scope, selOption, 'formentry');
  }    
});  

function sel$this->scope (value, text, source) {
  document.getElementById('togsearch$this->scope').style.display='none';
  document.getElementById('togselect$this->scope').style.display='block';

  setSource$this->scope = source;
  selectId$this->scope = value;
  document.getElementById('search$this->scope').value=text;
  document.getElementById('hint$this->scope').innerHTML='';
  document.getElementById('hint$this->scope').style.border='0px';
  document.getElementById('search$this->scope').focus();

  set$this->scope$this->iterator (selectId$this->scope, '', 'formentry');

  if ( selectId$this->scope > 0)
    options$this->scope (selectId$this->scope);

}

    
function listener$this->scope (message) {
  var key = Object.keys(message); 
  
  if (message[key][2] != 'dbresult') {
    document.getElementById('togsearch$this->scope').style.display='none';
    document.getElementById('togselect$this->scope').style.display='block';
  }

  if (message[key][0] > 0)
    options$this->scope (message[key][0]);
}  

function set$this->scope$this->iterator (dbValue, dbText, source) {

  setState$this->scope = source;

  $('#$this->scope.$this->iterator option[value='+dbValue+']').prop('selected',true);

  var msgContent = [];
  msgContent.$this->scope = [selectId$this->scope, '', setState$this->scope];
  $this->postMessages

  if ('$this->clickCommit' == 1) {
    var msgContent = [];
    msgContent.commit = [1, 'Yes', setState$this->scope];
    $this->postMessages
  }
  
  setState$this->scope = 'formentry';
}

multiFunction['$this->scope'] = {
  set$this->scope$this->iterator: set$this->scope$this->iterator
};  

function genHints$this->scope(list) {
  var layout='';
  var source = 'formentry';

  for (var i=0; i<list.length; i++) {

    var hint = list[i].hint;
    var args = list[i].id + ', \'' + hint + '\'' + ', \'' + source + '\'';

	layout += '<a href=\"#\" onclick=\"sel$this->scope(' + args + ');\">' + hint + '</a><br>';
  }	
  return layout;
} 
 
 
function result$this->scope (pattern) {
  if (pattern.length == 0) { 
    document.getElementById('hint$this->scope').innerHTML='';
    document.getElementById('hint$this->scope').style.border='0px';
  }

  else {
    var xhr = new XMLHttpRequest();
    var params = 'pattern=' + pattern;

    xhr.open('POST', 'ajax/res$this->scope.php', true);
    xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
    xhr.onreadystatechange = function() {//Call function when the state changes.
      if(xhr.readyState == 4 && xhr.status == 200) {
        var response = JSON.parse(xhr.responseText)
     
        document.getElementById('hint$this->scope').innerHTML=genHints$this->scope(response);
        document.getElementById('hint$this->scope').style.border='1px';
      }
    }  
    xhr.send(params);
  }  
}

function genOptions$this->scope(options) {

  var layout='<option value=0>Select</option>';

  for (var i=0; i<options.length; i++) {

    var selected = '';
    var value = options[i].id;
    var text = options[i].text
    if (value == selectId$this->scope)
      selected = ' selected';    
    
    layout += '<option value=' + value + selected + '>' + text + '</option>';
  }
  return layout;
} 
	  
function options$this->scope (id) {
  var xhr = new XMLHttpRequest();

  var params = 'sumid=' + id;

  xhr.open('POST', 'ajax/get$this->scope.php', true);
  xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
  xhr.onreadystatechange = function() {//Call a function when the state changes.
    if(xhr.readyState == 4 && xhr.status == 200) {
      var response = JSON.parse(xhr.responseText)
      document.getElementById('select$this->scope').innerHTML=genOptions$this->scope(response);
    }
  }  
  xhr.send(params);
}


    ";
    return $script;
  }
}

?>
