 <?php 

class SelectOption  {
  private $scope;
  private $label;
  private $selectId;
  private $options;
  private $iterator;
  private $prompt;
  private $postMessages;

  public function __construct($entry) {

    if (isset($entry)) {
      $this->scope  = $entry->scope;
      $this->label  = $entry->label;
      $this->selectId = $entry->selectId;
      $this->iterator = $entry->iterator;

      if (isset($entry->clickAction)) {
        if ($entry->clickAction == "commit")
          $this->clickCommit = 1;
      }
      else
        $this->clickCommit = 0;

      if (isset($entry->selectId))
        $this->selectId = $entry->selectId;
      else
        $this->selectId = 0;

      if (isset($entry->options))
        $this->options = $entry->options;
      else
        $this->options[] = NULL;
      $this->optCount = count($this->options);    

      if (isset($entry->prompt))
        $this->prompt = $entry->prompt;
      else
        $this->prompt = "Select";

      $this->postMessages = "";
      if (null !== $entry->listeners) {
        $listeners = explode(",", $entry->listeners);
        for ($i=0; $i<count($listeners); $i++) {
          $this->postMessages .= "listener" . $listeners[$i] . "(msgContent); ";
        }
      }    
    }
  }
  
  public function outputLayout() {
  
    $layout = "
  <label style='width:100%'>$this->label</label>
  <select id='$this->scope' class='$this->iterator'>
    <option value=0 selected>$this->prompt</option>
     ";

    foreach ($this->options as $item) {
      $value = $item->id;
      $text  = $item->descr;
 	  $attribute = "";	

      if ($item->id === $this->selectId || $this->optCount == 1)
        $attribute = " selected";

      $layout .= "
    <option value=" . $value . $attribute . " >" . $text . "</option>
      ";
    }
  
    $layout .= "
  </select>
	";
	return $layout;
  }	

  public function outputScript() {

    $this->iterator = str_replace(" ", ".", $this->iterator);

    $script = "

var selectId$this->scope = $this->selectId; 
var setState$this->scope = 'formentry';

function set$this->scope$this->iterator (dbValue, dbText, source) {
  selectId$this->scope = dbValue;
  setState$this->scope = source;

  $('#$this->scope.$this->iterator option[value='+dbValue+']').prop('selected',true);

  var msgContent = [];
  msgContent.$this->scope = [selectId$this->scope, '', setState$this->scope];
  $this->postMessages

  if ('$this->clickCommit' == 1) {
    var msgContent = [];
    msgContent.commit = [1, 'Yes', setState$this->scope];
    $this->postMessages
  }
  
  setState$this->scope = 'formentry';
}

multiFunction['$this->scope'] = {
  set$this->scope$this->iterator: set$this->scope$this->iterator
};  

$(document).on('change', '#$this->scope', function (e) {

  if (setState$this->scope == 'formentry') {
    selectId$this->scope = $(this).val();
    var selOption = $(this).text();
    set$this->scope$this->iterator (selectId$this->scope, selOption, 'formentry');
  }    
});  
    
function listener$this->scope (message) {
  var key = Object.keys(message); 
//alert (message[key][0]);
  if (message[key][0] > 0)
    get$this->scope (message[key][0]);
}  

function gen$this->scope(options) {
  var layout='<option value=0>Select</option>';
  var value;
  var text;
  var selected;

  var optLength = options.length;
  for (var i=0; i<options.length; i++) {
 
    selected = '';
    value = options[i].id;
    text = options[i].descr
    if (value == selectId$this->scope || optLength == 1)
      selected = ' selected';    
    
    layout += '<option value=' + value + selected + '>' + text + '</option>';
  }
  return layout;
} 
	  
function get$this->scope (id) {
  var xhr = new XMLHttpRequest();

  var params = 'sumid=' + id;

  xhr.open('POST', 'ajax/get$this->scope.php', true);
  xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
  xhr.onreadystatechange = function() {//Call a function when the state changes.
    if(xhr.readyState == 4 && xhr.status == 200) {
      var response = JSON.parse(xhr.responseText)
      document.getElementById('$this->scope').innerHTML=gen$this->scope(response);
    }
  }  
  xhr.send(params);
}

    "; 
    return $script;
  }
}

?>